@@ -11,6 +11,10 @@ from .packet import BinLogPacketWrapper
 from .constants.BINLOG import TABLE_MAP_EVENT, ROTATE_EVENT
 from .event import NotImplementedEvent
 
+
+MYSQL_EXPECTED_ERROR_CODES = [2013, 2006] #2013 Connection Lost
+                                          #2006 MySQL server has gone away
+
 class BinLogStreamReader(object):
     """Connect to replication stream and read event
     """
@@ -114,7 +118,7 @@ class BinLogStreamReader(object):
         prelude += struct.pack('<I', self.__server_id)
         prelude += self.log_file.encode()
 
-        if pymysql.VERSION < (0, 6, None):
+        if pymysql.__version__ < "0.6":
             self._stream_connection.wfile.write(prelude)
             self._stream_connection.wfile.flush()
         else:
@@ -130,14 +134,13 @@ class BinLogStreamReader(object):
                 self.__connect_to_ctl()
 
             try:
-                if pymysql.VERSION < (0, 6, None):
+                if pymysql.__version__ < "0.6":
                     pkt = self._stream_connection.read_packet()
                 else:
                     pkt = self._stream_connection._read_packet()
             except pymysql.OperationalError as error:
                 code, message = error.args
-                # 2013: Connection Lost
-                if code == 2013:
+                if code in MYSQL_EXPECTED_ERROR_CODES:
                     self.__connected_stream = False
                     continue
 
@@ -196,8 +199,7 @@ class BinLogStreamReader(object):
                 return cur.fetchall()
             except pymysql.OperationalError as error:
                 code, message = error.args
-                # 2013: Connection Lost
-                if code == 2013:
+                if code in MYSQL_EXPECTED_ERROR_CODES:
                     self.__connected_ctl = False
                     continue
                 else:
