@@ -1,15 +1,19 @@
+# -*- coding: utf-8 -*-
+
+import copy
+import datetime
+import platform
+import unittest
+
+from decimal import Decimal
+
 from pymysqlreplication.tests import base
-from pymysqlreplication import BinLogStreamReader
 from pymysqlreplication.event import *
 from pymysqlreplication.constants.BINLOG import *
 from pymysqlreplication.row_event import *
 
-from decimal import Decimal
-import datetime
-import time
-import unittest
-import copy
-import platform
+__all__ = ["TestDataType"]
+
 
 class TestDataType(base.PyMySQLReplicationTestCase):
     def create_and_insert_value(self, create_query, insert_query):
@@ -32,7 +36,7 @@ class TestDataType(base.PyMySQLReplicationTestCase):
 
         event = self.stream.fetchone()
         if self.isMySQL56AndMore():
-            self.assertEqual(event.event_type, WRITE_ROWS_EVENT)
+            self.assertEqual(event.event_type, WRITE_ROWS_EVENT_V2)
         else:
             self.assertEqual(event.event_type, WRITE_ROWS_EVENT_V1)
         self.assertIsInstance(event, WriteRowsEvent)
@@ -54,6 +58,23 @@ class TestDataType(base.PyMySQLReplicationTestCase):
         event = self.create_and_insert_value(create_query, insert_query)
         self.assertEqual(event.rows[0]["values"]["test"], Decimal("42000.123456"))
 
+    def test_decimal_long_values_1(self):
+        create_query = "CREATE TABLE test (\
+            test DECIMAL(20,10) \
+        )"
+        insert_query = "INSERT INTO test VALUES(9000000123.123456)"
+        event = self.create_and_insert_value(create_query, insert_query)
+        self.assertEqual(event.rows[0]["values"]["test"], Decimal("9000000123.123456"))
+
+    def test_decimal_long_values_2(self):
+        create_query = "CREATE TABLE test (\
+            test DECIMAL(20,10) \
+        )"
+        insert_query = "INSERT INTO test VALUES(9000000123.0000012345)"
+        event = self.create_and_insert_value(create_query, insert_query)
+        self.assertEqual(event.rows[0]["values"]["test"],
+                Decimal("9000000123.0000012345"))
+
     def test_decimal_negative_values(self):
         create_query = "CREATE TABLE test (\
             test DECIMAL(20,10) \
@@ -109,6 +130,30 @@ class TestDataType(base.PyMySQLReplicationTestCase):
         self.assertEqual(event.rows[0]["values"]["id"], 255)
         self.assertEqual(event.rows[0]["values"]["test"], -128)
 
+    def test_tiny_maps_to_boolean_true(self):
+        create_query = "CREATE TABLE test (id TINYINT UNSIGNED NOT NULL, test BOOLEAN)"
+        insert_query = "INSERT INTO test VALUES(1, TRUE)"
+        event = self.create_and_insert_value(create_query, insert_query)
+        self.assertEqual(event.rows[0]["values"]["id"], 1)
+        self.assertEqual(type(event.rows[0]["values"]["test"]), type(True))
+        self.assertEqual(event.rows[0]["values"]["test"], True)
+
+    def test_tiny_maps_to_boolean_false(self):
+        create_query = "CREATE TABLE test (id TINYINT UNSIGNED NOT NULL, test BOOLEAN)"
+        insert_query = "INSERT INTO test VALUES(1, FALSE)"
+        event = self.create_and_insert_value(create_query, insert_query)
+        self.assertEqual(event.rows[0]["values"]["id"], 1)
+        self.assertEqual(type(event.rows[0]["values"]["test"]), type(True))
+        self.assertEqual(event.rows[0]["values"]["test"], False)
+
+    def test_tiny_maps_to_none(self):
+        create_query = "CREATE TABLE test (id TINYINT UNSIGNED NOT NULL, test BOOLEAN)"
+        insert_query = "INSERT INTO test VALUES(1, NULL)"
+        event = self.create_and_insert_value(create_query, insert_query)
+        self.assertEqual(event.rows[0]["values"]["id"], 1)
+        self.assertEqual(type(event.rows[0]["values"]["test"]), type(None))
+        self.assertEqual(event.rows[0]["values"]["test"], None)
+
     def test_short(self):
         create_query = "CREATE TABLE test (id SMALLINT UNSIGNED NOT NULL, test SMALLINT)"
         insert_query = "INSERT INTO test VALUES(65535, -32768)"
@@ -177,12 +222,15 @@ class TestDataType(base.PyMySQLReplicationTestCase):
         self.assertEqual(event.rows[0]["values"]["test"], -9223372036854775808)
 
     def test_int24(self):
-        create_query = "CREATE TABLE test (id MEDIUMINT UNSIGNED NOT NULL, test MEDIUMINT, test2 MEDIUMINT)"
-        insert_query = "INSERT INTO test VALUES(16777215, 8388607, -8388608)"
+        create_query = "CREATE TABLE test (id MEDIUMINT UNSIGNED NOT NULL, test MEDIUMINT, test2 MEDIUMINT, test3 MEDIUMINT, test4 MEDIUMINT, test5 MEDIUMINT)"
+        insert_query = "INSERT INTO test VALUES(16777215, 8388607, -8388608, 8, -8, 0)"
         event = self.create_and_insert_value(create_query, insert_query)
         self.assertEqual(event.rows[0]["values"]["id"], 16777215)
         self.assertEqual(event.rows[0]["values"]["test"], 8388607)
         self.assertEqual(event.rows[0]["values"]["test2"], -8388608)
+        self.assertEqual(event.rows[0]["values"]["test3"], 8)
+        self.assertEqual(event.rows[0]["values"]["test4"], -8)
+        self.assertEqual(event.rows[0]["values"]["test5"], 0)
 
     def test_date(self):
         create_query = "CREATE TABLE test (test DATE);"
@@ -191,10 +239,11 @@ class TestDataType(base.PyMySQLReplicationTestCase):
         self.assertEqual(event.rows[0]["values"]["test"], datetime.date(1984, 12, 3))
 
     def test_zero_date(self):
-        create_query = "CREATE TABLE test (id INTEGER, test DATE);"
-        insert_query = "INSERT INTO test (id) VALUES(1)"
+        create_query = "CREATE TABLE test (id INTEGER, test DATE, test2 DATE);"
+        insert_query = "INSERT INTO test (id, test2) VALUES(1, '0000-01-21')"
         event = self.create_and_insert_value(create_query, insert_query)
         self.assertEqual(event.rows[0]["values"]["test"], None)
+        self.assertEqual(event.rows[0]["values"]["test2"], None)
 
     def test_time(self):
         create_query = "CREATE TABLE test (test TIME);"
@@ -377,8 +426,6 @@ class TestDataType(base.PyMySQLReplicationTestCase):
         event = self.create_and_insert_value(create_query, insert_query)
         self.assertMultiLineEqual(event.rows[0]["values"]["test"], str)
 
-__all__ = ["TestDataType"]
 
 if __name__ == "__main__":
-    import unittest
     unittest.main()
